@@ -57,8 +57,15 @@ def parse(
                 error = f"Template {filename} is malformed: {err.problem}. Tried to parse {filename} as JSON but got error: {json_err}"
                 LOGGER.info(error)
     except YAMLError as err:
-        error = f"Parsing error in file: {filename} - {err}"
-        LOGGER.info(error)
+        if hasattr(err, 'problem') and err.problem in ["expected ',' or '}', but got '<scalar>'"]:
+            try:
+                (template, template_lines) = json_parse(filename, allow_nulls=False)
+            except Exception as json_err:  # pylint: disable=W0703
+                error = f"Template {filename} is malformed: {err.problem}. Tried to parse {filename} as JSON but got error: {json_err}"
+                LOGGER.info(error)
+        else:
+            error = f"Parsing error in file: {filename} - {err}"
+            LOGGER.info(error)
 
     if error:
         out_parsing_errors[filename] = error
