@@ -80,6 +80,17 @@ def persist_checks_results(
     return checks_results_paths
 
 
+def persist_run_metadata(
+    run_metadata: dict[str, str | list[str]], s3_client: BaseClient, bucket: str, full_repo_object_key: str
+) -> None:
+    object_path = f'{full_repo_object_key}/{checkov_results_prefix}/run_metadata.json'
+    try:
+        s3_client.put_object(Bucket=bucket, Key=object_path, Body=json.dumps(run_metadata, indent=2))
+    except Exception:
+        logging.error(f"failed to persist run metadata into S3 bucket {bucket}", exc_info=True)
+        raise
+
+
 def enrich_and_persist_checks_metadata(
     scan_reports: list[Report], s3_client: BaseClient, bucket: str, full_repo_object_key: str
 ) -> dict[str, dict[str, str]]:
@@ -89,10 +100,6 @@ def enrich_and_persist_checks_metadata(
     """
     checks_metadata_paths: dict[str, dict[str, str]] = {}
     for scan_report in scan_reports:
-        if scan_report.is_empty():
-            # only save checks metadata for reports with check results
-            continue
-
         check_type = scan_report.check_type
         checks_metadata_object = _extract_checks_metadata(scan_report, full_repo_object_key)
         checks_metadata_object_path = f'{full_repo_object_key}/{checkov_results_prefix}/{check_type}/checks_metadata.json'
