@@ -41,6 +41,8 @@ from checkov.common.checks_infra.solvers import (
     LengthGreaterThanOrEqualAttributeSolver,
     IsTrueAttributeSolver,
     IsFalseAttributeSolver,
+    IntersectsAttributeSolver,
+    NotIntersectsAttributeSolver
 )
 from checkov.common.checks_infra.solvers.connections_solvers.connection_one_exists_solver import \
     ConnectionOneExistsSolver
@@ -48,6 +50,7 @@ from checkov.common.graph.checks_infra.base_check import BaseGraphCheck
 from checkov.common.graph.checks_infra.base_parser import BaseGraphCheckParser
 from checkov.common.graph.checks_infra.enums import SolverType
 from checkov.common.graph.checks_infra.solvers.base_solver import BaseSolver
+from checkov.common.util.type_forcers import force_list
 
 if TYPE_CHECKING:
     from checkov.common.checks_infra.solvers.attribute_solvers.base_attribute_solver import BaseAttributeSolver
@@ -88,6 +91,8 @@ operators_to_attributes_solver_classes: dict[str, Type[BaseAttributeSolver]] = {
     "length_less_than_or_equal": LengthLessThanOrEqualAttributeSolver,
     "is_true": IsTrueAttributeSolver,
     "is_false": IsFalseAttributeSolver,
+    "intersects": IntersectsAttributeSolver,
+    "not_intersects": NotIntersectsAttributeSolver
 }
 
 operators_to_complex_solver_classes: dict[str, Type[BaseComplexSolver]] = {
@@ -150,7 +155,7 @@ class NXGraphCheckParser(BaseGraphCheckParser):
             for sub_solver in sub_solvers:
                 check.sub_checks.append(self._parse_raw_check(sub_solver, resources_types))
             resources_types_of_sub_solvers = [
-                q.resource_types for q in check.sub_checks if q is not None and q.resource_types is not None
+                force_list(q.resource_types) for q in check.sub_checks if q is not None and q.resource_types is not None
             ]
             check.resource_types = list(set(sum(resources_types_of_sub_solvers, [])))
             if any(q.type in [SolverType.CONNECTION, SolverType.COMPLEX_CONNECTION] for q in check.sub_checks):
