@@ -1,6 +1,6 @@
 import json
 import logging
-from typing import List, Optional, Any, Dict
+from typing import Optional, Any, Dict
 
 from checkov.common.graph.checks_infra.enums import Operators
 from checkov.common.checks_infra.solvers.attribute_solvers.base_attribute_solver import BaseAttributeSolver
@@ -13,6 +13,7 @@ class ContainsAttributeSolver(BaseAttributeSolver):
 
     def _get_operation(self, vertex: Dict[str, Any], attribute: Optional[str]) -> bool:  # type:ignore[override]
         att = vertex.get(attribute, "{}")  # type:ignore[arg-type]  # due to attribute can be None
+        att = "{}" if att is None else att
         if isinstance(att, str):
             try:
                 att = json.loads(att.replace("'", '"'))
