@@ -1,4 +1,4 @@
-from typing import List, Optional, Any, Dict
+from typing import Optional, Any, Dict
 
 from .length_equals_attribute_solver import LengthEqualsAttributeSolver
 from checkov.common.graph.checks_infra.enums import Operators
