@@ -1,12 +1,15 @@
-from typing import Optional, List, Tuple, Dict, Any
+from __future__ import annotations
 
-from networkx.classes.digraph import DiGraph
+from typing import Optional, List, Tuple, Dict, Any, TYPE_CHECKING
 
 from checkov.common.graph.checks_infra.enums import Operators
 from checkov.common.graph.checks_infra.solvers.base_solver import BaseSolver
 from checkov.common.checks_infra.solvers.connections_solvers.complex_connection_solver import ComplexConnectionSolver
 from checkov.common.graph.graph_builder.graph_components.attribute_names import CustomAttributes
 
+if TYPE_CHECKING:
+    from networkx import DiGraph
+
 
 class AndConnectionSolver(ComplexConnectionSolver):
     operator = Operators.AND  # noqa: CCE003  # a static attribute
