@@ -1,12 +1,13 @@
 from __future__ import annotations
 
-from typing import Any, Callable
-
-from networkx import DiGraph
+from typing import Any, Callable, TYPE_CHECKING
 
 from checkov.common.graph.checks_infra.enums import SolverType
 from checkov.common.graph.checks_infra.solvers.base_solver import BaseSolver
 
+if TYPE_CHECKING:
+    from networkx import DiGraph
+
 
 class BaseFilterSolver(BaseSolver):
     def __init__(self, resource_types: list[str], attribute: str | None, value: Any) -> None:
