@@ -47,7 +47,7 @@ ignored_directories = IGNORED_DIRECTORIES_ENV.split(",")
 
 class BaseRunner(ABC, Generic[_GraphManager]):
     check_type = ""
-    definitions = None
+    definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] | None = None
     context: dict[str, dict[str, Any]] | None = None
     breadcrumbs = None
     external_registries: list[BaseRegistry] | None = None
@@ -87,7 +87,7 @@ class BaseRunner(ABC, Generic[_GraphManager]):
 
     def set_external_data(
             self,
-            definitions: dict[str, dict[str, Any]] | None,
+            definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] | None,
             context: dict[str, dict[str, Any]] | None,
             breadcrumbs: dict[str, dict[str, Any]] | None,
             **kwargs: Any,
