@@ -31,12 +31,12 @@ class GhaMetadata(TypedDict):
 class Runner(BaseRunner[None]):  # if a graph is added, Any needs to replaced
     def __init__(self) -> None:
         super().__init__()
+        self.definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] = {}
         self.map_file_path_to_gha_metadata_dict: dict[str, GhaMetadata] = {}
 
     def _load_files(
             self,
             files_to_load: list[str],
-            definitions: dict[str, dict[str, Any] | list[dict[str, Any]]],
             definitions_raw: dict[str, list[tuple[int, str]]],
             filename_fn: Callable[[str], str] | None = None,
     ) -> None:
@@ -44,7 +44,7 @@ class Runner(BaseRunner[None]):  # if a graph is added, Any needs to replaced
         results = parallel_runner.run_function(lambda f: (f, self._parse_file(f)), files_to_load)
         for file, result in results:
             if result:
-                (definitions[file], definitions_raw[file]) = result
+                (self.definitions[file], definitions_raw[file]) = result
                 definition = result[0]
                 if self.check_type == CheckType.GITHUB_ACTIONS and isinstance(definition, dict):
                     workflow_name = definition.get('name', '')
@@ -73,7 +73,6 @@ class Runner(BaseRunner[None]):  # if a graph is added, Any needs to replaced
 
         registry = self.import_registry()
 
-        definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] = {}
         definitions_raw: dict[str, list[tuple[int, str]]] = {}
 
         report = Report(self.check_type)
@@ -90,20 +89,20 @@ class Runner(BaseRunner[None]):  # if a graph is added, Any needs to replaced
                 registry.load_external_checks(directory)
 
         if files:
-            self._load_files(files, definitions, definitions_raw)
+            self._load_files(files, definitions_raw)
 
         if root_folder:
             for root, d_names, f_names in os.walk(root_folder):
                 filter_ignored_paths(root, d_names, runner_filter.excluded_paths, self.included_paths())
                 filter_ignored_paths(root, f_names, runner_filter.excluded_paths, self.included_paths())
                 files_to_load = [os.path.join(root, f_name) for f_name in f_names]
-                self._load_files(files_to_load=files_to_load, definitions=definitions, definitions_raw=definitions_raw)
+                self._load_files(files_to_load=files_to_load, definitions_raw=definitions_raw)
 
-        self.pbar.initiate(len(definitions))
-        for file_path in definitions.keys():
+        self.pbar.initiate(len(self.definitions))
+        for file_path in self.definitions.keys():
             self.pbar.set_additional_data({'Current File Scanned': os.path.relpath(file_path, root_folder)})
             skipped_checks = collect_suppressions_for_context(definitions_raw[file_path])
-            results = registry.scan(file_path, definitions[file_path], skipped_checks, runner_filter)  # type:ignore[arg-type] # this is overridden in the subclass
+            results = registry.scan(file_path, self.definitions[file_path], skipped_checks, runner_filter)  # type:ignore[arg-type] # this is overridden in the subclass
             for key, result in results.items():
                 result_config = result["results_configuration"]
                 start = 0
@@ -127,7 +126,7 @@ class Runner(BaseRunner[None]):  # if a graph is added, Any needs to replaced
                         code_block=definitions_raw[file_path][start - 1:end + 1],
                         file_path=f"/{os.path.relpath(file_path, root_folder)}",
                         file_line_range=[start, end + 1],
-                        resource=self.get_resource(file_path, key, check.supported_entities, definitions[file_path]),  # type:ignore[arg-type]  # key is str not BaseCheck
+                        resource=self.get_resource(file_path, key, check.supported_entities, self.definitions[file_path]),  # type:ignore[arg-type]  # key is str not BaseCheck
                         evaluations=None,
                         check_class=check.__class__.__module__,
                         file_abs_path=os.path.abspath(file_path),
