@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import Any
+
 from checkov.common.models.enums import CheckResult
 
 from checkov.gitlab_ci.checks.base_gitlab_ci_check import BaseGitlabCICheck
@@ -5,17 +9,17 @@ from checkov.yaml_doc.enums import BlockType
 
 
 class SuspectCurlInScript(BaseGitlabCICheck):
-    def __init__(self):
+    def __init__(self) -> None:
         name = "Suspicious use of curl with CI environment variables in script"
         id = "CKV_GITLABCI_1"
         super().__init__(
             name=name,
             id=id,
             block_type=BlockType.ARRAY,
-            supported_entities=['*.script[]']
+            supported_entities=('*.script[]',)
         )
 
-    def scan_entity_conf(self, conf):
+    def scan_entity_conf(self, conf: dict[str, Any]) -> CheckResult:
         if "curl" in conf:
             badstuff = ('curl', '$CI_')
             lines = conf.split("\n")
@@ -24,4 +28,5 @@ class SuspectCurlInScript(BaseGitlabCICheck):
                     return CheckResult.FAILED, conf
         return CheckResult.PASSED, conf
 
+
 check = SuspectCurlInScript()
