@@ -6,7 +6,7 @@ import logging
 import os
 import subprocess  # nosec
 import tempfile
-from typing import Any, Type, Optional, List
+from typing import Any, Type
 import yaml
 
 from checkov.common.bridgecrew.check_type import CheckType
@@ -19,24 +19,32 @@ from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.runners.base_runner import BaseRunner, filter_ignored_paths
 from checkov.helm.registry import registry
 from checkov.kubernetes.graph_builder.local_graph import KubernetesLocalGraph
-from checkov.kubernetes.runner import Runner as k8_runner
+from checkov.kubernetes.runner import Runner as k8_runner, handle_timeout
 from checkov.runner_filter import RunnerFilter
+import signal
 
 
 class K8sHelmRunner(k8_runner):
-    def __init__(self, graph_class: Type[LocalGraph] = KubernetesLocalGraph,
-                 db_connector: NetworkxConnector = NetworkxConnector(),
-                 source: str = "Kubernetes",
-                 graph_manager: Optional[GraphManager] = None,
-                 external_registries: Optional[List[BaseRegistry]] = None) -> None:
+    def __init__(
+        self,
+        graph_class: Type[LocalGraph] = KubernetesLocalGraph,
+        db_connector: NetworkxConnector | None = None,
+        source: str = "Kubernetes",
+        graph_manager: GraphManager | None = None,
+        external_registries: list[BaseRegistry] | None = None
+    ) -> None:
+        db_connector = db_connector or NetworkxConnector()
+
         self.check_type = CheckType.HELM
         super().__init__(graph_class, db_connector, source, graph_manager, external_registries)
         self.chart_dir_and_meta = []
         self.pbar.turn_off_progress_bar()
 
     def run(self, root_folder: str | None, external_checks_dir: list[str] | None = None, files: list[str] | None = None,
-            runner_filter: RunnerFilter = RunnerFilter(), collect_skip_comments: bool = True) -> Report:
+            runner_filter: RunnerFilter | None = None, collect_skip_comments: bool = True) -> Report:
+        runner_filter = runner_filter or RunnerFilter()
         report = Report(self.check_type)
+
         if not self.chart_dir_and_meta:
             return report
         if external_checks_dir:
@@ -60,11 +68,11 @@ class K8sHelmRunner(k8_runner):
 
 
 class Runner(BaseRunner):
-    check_type = CheckType.HELM
-    helm_command = 'helm'
-    system_deps = True
+    check_type = CheckType.HELM  # noqa: CCE003  # a static attribute
+    helm_command = 'helm'  # noqa: CCE003  # a static attribute
+    system_deps = True  # noqa: CCE003  # a static attribute
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.file_names = ['Chart.yaml']
         self.target_folder_path = ''
@@ -78,7 +86,7 @@ class Runner(BaseRunner):
     def parse_helm_chart_details(chart_path: str) -> dict[str, Any] | None:
         with open(f"{chart_path}/Chart.yaml", 'r') as chartyaml:
             try:
-                chart_meta = yaml.safe_load(chartyaml)
+                chart_meta: dict[str, Any] = yaml.safe_load(chartyaml)
             except (yaml.YAMLError, UnicodeDecodeError):
                 logging.info(f"Failed to load chart metadata from {chart_path}/Chart.yaml.", exc_info=True)
                 return None
@@ -101,12 +109,13 @@ class Runner(BaseRunner):
                 return self.check_type
         except Exception:
             logging.info(f"Error running necessary tools to process {self.check_type} checks.")
-            return self.check_type
+
+        return self.check_type
 
     @staticmethod
     def _parse_output(target_dir: str, output: bytes) -> None:
-        output = str(output, 'utf-8')
-        reader = io.StringIO(output)
+        output_str = str(output, 'utf-8')
+        reader = io.StringIO(output_str)
         cur_source_file = None
         cur_writer = None
         last_line_dashes = False
@@ -151,7 +160,7 @@ class Runner(BaseRunner):
             cur_writer.close()
 
     @staticmethod
-    def _get_target_dir(chart_item, root_folder, target_folder_path):
+    def _get_target_dir(chart_item: tuple[str, dict[str, Any]], root_folder: str, target_folder_path: str) -> str | None:
         (chart_dir, chart_meta) = chart_item
         target_dir = chart_dir.replace(root_folder, f'{target_folder_path}/')
         target_dir.replace("//", "/")
@@ -168,16 +177,22 @@ class Runner(BaseRunner):
             target_dir = target_dir[:-len(chart_name)]
         return target_dir
 
-    @staticmethod 
-    def get_binary_output(chart_item, target_dir, helm_command, runner_filter):
+    @staticmethod
+    def get_binary_output(
+        chart_item: tuple[str, dict[str, Any]], target_dir: str, helm_command: str, runner_filter: RunnerFilter, timeout: int = 3600
+    ) -> tuple[bytes, tuple[str, dict[str, Any]]] | tuple[None, None]:
         (chart_dir, chart_meta) = chart_item
         chart_name = chart_meta.get('name', chart_meta.get('Name'))
         chart_version = chart_meta.get('version', chart_meta.get('Version'))
         logging.info(
             f"Processing chart found at: {chart_dir}, name: {chart_name}, version: {chart_version}")
         # dependency list is nicer to parse than dependency update.
-        helm_binary_list_chart_deps = subprocess.Popen([helm_command, 'dependency', 'list', chart_dir], stdout=subprocess.PIPE, stderr=subprocess.PIPE)  # nosec
-        o, e = helm_binary_list_chart_deps.communicate()
+        try:
+            helm_binary_list_chart_deps = subprocess.Popen([helm_command, 'dependency', 'list', chart_dir], stdout=subprocess.PIPE, stderr=subprocess.PIPE)  # nosec
+            o, e = helm_binary_list_chart_deps.communicate()
+        except Exception:
+            logging.error('Error run helm command', exc_info=True)
+            return None, None
         logging.debug(
             f"Ran helm command to get dependency output. Chart: {chart_name}. dir: {target_dir}. Output: {str(o, 'utf-8')}. Errors: {str(e, 'utf-8')}")
         if e:
@@ -194,27 +209,43 @@ class Runner(BaseRunner):
                 helm_command_args.append("--values")
                 helm_command_args.append(var)
 
+        signal.signal(signal.SIGALRM, handle_timeout)
+        signal.alarm(timeout)
         try:
             # --dependency-update needed to pull in deps before templating.
             proc = subprocess.Popen(helm_command_args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)  # nosec
             o, e = proc.communicate()
+            signal.alarm(0)
             if e:
                 logging.warning(
                     f"Error processing helm chart {chart_name} at dir: {chart_dir}. Working dir: {target_dir}. Error details: {str(e, 'utf-8')}")
                 return None, None
             logging.debug(
                 f"Ran helm command to template chart output. Chart: {chart_name}. dir: {target_dir}. Output: {str(o, 'utf-8')}. Errors: {str(e, 'utf-8')}")
+            logging.info(f'Done helm run for: {chart_dir}')
             return o, chart_item
 
-        except Exception:
-            logging.info(
-                f"Error processing helm chart {chart_name} at dir: {chart_dir}. Working dir: {target_dir}.",
-                exc_info=True,
-            )
+        except Exception as e:
+            signal.alarm(0)
+            if isinstance(e, TimeoutError):
+                logging.info(
+                    f"Error processing helm chart {chart_name} at dir: {chart_dir}. Working dir: {target_dir}. got timeout"
+                )
+            else:
+                logging.info(
+                    f"Error processing helm chart {chart_name} at dir: {chart_dir}. Working dir: {target_dir}.",
+                    exc_info=True,
+                )
             return None, None
 
     @staticmethod
-    def _convert_chart_to_k8s(chart_item, root_folder, target_folder_path, helm_command, runner_filter):
+    def _convert_chart_to_k8s(
+        chart_item: tuple[str, dict[str, Any]],
+        root_folder: str,
+        target_folder_path: str,
+        helm_command: str,
+        runner_filter: RunnerFilter,
+    ) -> None:
         target_dir = Runner._get_target_dir(chart_item, root_folder, target_folder_path)
         if not target_dir:
             return
@@ -230,35 +261,50 @@ class Runner(BaseRunner):
             )
 
     @staticmethod
-    def _get_chart_dir_and_meta(root_folder, files, runner_filter):
+    def _get_chart_dir_and_meta(
+        root_folder: str, files: list[str], runner_filter: RunnerFilter
+    ) -> list[tuple[str, dict[str, Any]]]:
         chart_directories = find_chart_directories(root_folder, files, runner_filter.excluded_paths)
         chart_dir_and_meta = list(parallel_runner.run_function(
             lambda cd: (cd, Runner.parse_helm_chart_details(cd)), chart_directories))
         # remove parsing failures
         chart_dir_and_meta = [chart_meta for chart_meta in chart_dir_and_meta if chart_meta[1]]
         return chart_dir_and_meta
-    
+
     @staticmethod
-    def _get_processed_chart_dir_and_meta(chart_dir_and_meta, root_folder):
+    def _get_processed_chart_dir_and_meta(
+        chart_dir_and_meta: list[tuple[str, dict[str, Any]]], root_folder: str
+    ) -> list[tuple[str, dict[str, Any]]]:
         processed_chart_dir_and_meta = []
         for chart_dir, chart_meta in chart_dir_and_meta:
             processed_chart_dir_and_meta.append((chart_dir.replace(root_folder, ""), chart_meta))
         return processed_chart_dir_and_meta
 
-    def convert_helm_to_k8s(self, root_folder: str, files: list[str], runner_filter: RunnerFilter) -> list[tuple[Any, dict[str, Any]]]:
+    def convert_helm_to_k8s(
+        self, root_folder: str, files: list[str], runner_filter: RunnerFilter
+    ) -> list[tuple[Any, dict[str, Any]]]:
         self.root_folder = root_folder
         self.runner_filter = runner_filter
         self.target_folder_path = tempfile.mkdtemp()
         chart_dir_and_meta = Runner._get_chart_dir_and_meta(self.root_folder, files, self.runner_filter)
-        
-        list(parallel_runner.run_function(lambda cd: Runner._convert_chart_to_k8s(cd, self.root_folder, 
-                                                                                         self.target_folder_path, 
-                                                                                         self.helm_command, 
-                                                                                         self.runner_filter), chart_dir_and_meta))
+
+        list(
+            parallel_runner.run_function(
+                lambda cd: Runner._convert_chart_to_k8s(
+                    chart_item=cd,
+                    root_folder=self.root_folder,
+                    target_folder_path=self.target_folder_path,
+                    helm_command=self.helm_command,
+                    runner_filter=self.runner_filter,
+                ),
+                chart_dir_and_meta,
+            )
+        )
         return Runner._get_processed_chart_dir_and_meta(chart_dir_and_meta, self.root_folder)
 
     def run(self, root_folder: str | None, external_checks_dir: list[str] | None = None, files: list[str] | None = None,
-            runner_filter: RunnerFilter = RunnerFilter(), collect_skip_comments: bool = True) -> Report:
+            runner_filter: RunnerFilter | None = None, collect_skip_comments: bool = True) -> Report:
+        runner_filter = runner_filter or RunnerFilter()
         if not runner_filter.show_progress_bar:
             self.pbar.turn_off_progress_bar()
 
@@ -274,7 +320,7 @@ def fix_report_paths(report: Report, tmp_dir: str) -> None:
     report.resources = {r.replace(tmp_dir, '', 1) for r in report.resources}
 
 
-def get_skipped_checks(entity_conf: dict) -> List:
+def get_skipped_checks(entity_conf: dict[str, Any]) -> list[dict[str, str]]:
     skipped = []
     metadata = {}
     if not isinstance(entity_conf, dict):
@@ -301,7 +347,7 @@ def get_skipped_checks(entity_conf: dict) -> List:
     return skipped
 
 
-def find_chart_directories(root_folder: str, files: list[str], excluded_paths: list[str]) -> List[str]:
+def find_chart_directories(root_folder: str, files: list[str], excluded_paths: list[str]) -> list[str]:
     chart_directories = []
     if not excluded_paths:
         excluded_paths = []
