@@ -33,6 +33,14 @@ if TYPE_CHECKING:
     from checkov.common.graph.checks_infra.base_check import BaseGraphCheck
 
 
+class TimeoutError(Exception):
+    pass
+
+
+def handle_timeout(signum, frame):
+    raise TimeoutError('command got timeout')
+
+
 class Runner(BaseRunner):
     check_type = CheckType.KUBERNETES  # noqa: CCE003  # a static attribute
 
@@ -195,7 +203,7 @@ class Runner(BaseRunner):
                     check_name=check.name,
                     check_result=check_result,
                     code_block=entity_context.get("code_lines"),
-                    file_path=entity_file_path,
+                    file_path=get_relative_file_path(entity_file_abs_path, root_folder),
                     file_line_range=[entity_context.get("start_line"), entity_context.get("end_line")],
                     resource=entity.get(CustomAttributes.ID),
                     evaluations={},
@@ -208,6 +216,10 @@ class Runner(BaseRunner):
         return report
 
 
+def get_relative_file_path(file_abs_path: str, root_folder: str) -> str:
+    return f"/{os.path.relpath(file_abs_path, root_folder)}"
+
+
 def _get_entity_abs_path(root_folder: str | None, entity_file_path: str) -> str:
     if entity_file_path[0] == '/' and (root_folder and not entity_file_path.startswith(root_folder)):
         path_to_convert = (root_folder + entity_file_path) if root_folder else entity_file_path
