@@ -39,8 +39,9 @@ class RunnerFilter(object):
             use_enforcement_rules: bool = False,
             filtered_policy_ids: Optional[List[str]] = None,
             show_progress_bar: Optional[bool] = True,
-            secrets_scan_file_type: Optional[List[str]] = None,
-            run_image_referencer: bool = False
+            run_image_referencer: bool = False,
+            enable_secret_scan_all_files: bool = False,
+            black_list_secret_scan: Optional[List[str]] = None
     ) -> None:
 
         checks = convert_csv_string_arg_to_list(checks)
@@ -95,8 +96,9 @@ class RunnerFilter(object):
         self.var_files = var_files
         self.skip_cve_package = skip_cve_package
         self.filtered_policy_ids = filtered_policy_ids or []
-        self.secrets_scan_file_type = secrets_scan_file_type
         self.run_image_referencer = run_image_referencer
+        self.enable_secret_scan_all_files = enable_secret_scan_all_files
+        self.black_list_secret_scan = black_list_secret_scan
 
     def apply_enforcement_rules(self, enforcement_rule_configs: Dict[str, CodeCategoryConfiguration]) -> None:
         self.enforcement_rule_configs = {}
@@ -241,13 +243,14 @@ class RunnerFilter(object):
         show_progress_bar = obj.get('show_progress_bar')
         if show_progress_bar is None:
             show_progress_bar = True
-        secrets_scan_file_type = obj.get('secrets_scan_file_type')
         run_image_referencer = obj.get('run_image_referencer')
         if run_image_referencer is None:
             run_image_referencer = False
+        enable_secret_scan_all_files = bool(obj.get('enable_secret_scan_all_files'))
+        black_list_secret_scan = obj.get('black_list_secret_scan')
         runner_filter = RunnerFilter(framework, checks, skip_checks, include_all_checkov_policies,
                                      download_external_modules, external_modules_download_path, evaluate_variables,
                                      runners, skip_framework, excluded_paths, all_external, var_files,
                                      skip_cve_package, use_enforcement_rules, filtered_policy_ids, show_progress_bar,
-                                     secrets_scan_file_type, run_image_referencer)
+                                     run_image_referencer, enable_secret_scan_all_files, black_list_secret_scan)
         return runner_filter
