@@ -1,16 +1,20 @@
+from __future__ import annotations
+
+from typing import Any
+
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 
 
 class GoogleCloudPostgreSqlLogCheckpoints(BaseResourceCheck):
-    def __init__(self):
+    def __init__(self) -> None:
         name = "Ensure PostgreSQL database 'log_checkpoints' flag is set to 'on'"
         check_id = "CKV_GCP_51"
-        supported_resources = ['google_sql_database_instance']
-        categories = [CheckCategories.LOGGING]
+        supported_resources = ('google_sql_database_instance',)
+        categories = (CheckCategories.LOGGING,)
         super().__init__(name=name, id=check_id, categories=categories, supported_resources=supported_resources)
 
-    def scan_resource_conf(self, conf):
+    def scan_resource_conf(self, conf: dict[str, list[Any]]) -> CheckResult:
         """
             Looks for google_sql_database_instance which allows enables log checkouts on PostgreSQL DBs:
             :param
@@ -24,19 +28,19 @@ class GoogleCloudPostgreSqlLogCheckpoints(BaseResourceCheck):
                 flags = conf['settings'][0].get('database_flags')
                 if flags:
                     evaluated_keys_prefix = 'settings/[0]/database_flags'
-                    if isinstance(flags[0],list):  # treating use cases of the following database_flags parsing (list of list of dictionaries with strings):'database_flags': [[{'name': '<key>', 'value': '<value>'}, {'name': '<key>', 'value': '<value>'}]]
+                    if isinstance(flags[0], list):  # treating use cases of the following database_flags parsing (list of list of dictionaries with strings):'database_flags': [[{'name': '<key>', 'value': '<value>'}, {'name': '<key>', 'value': '<value>'}]]
                         flags = flags[0]
                         evaluated_keys_prefix += '/[0]'
                     else:  # treating use cases of the following database_flags parsing (list of dictionaries with arrays): 'database_flags': [{'name': ['<key>'], 'value': ['<value>']},{'name': ['<key>'], 'value': ['<value>']}]
                         flags = [{key: flag[key][0] for key in flag} for flag in flags]
                     for flag in flags:
-                        if (flag['name'] == 'log_checkpoints') and (flag['value'] == 'off'):
+                        if (flag['name'] == 'log_checkpoints') and (flag['value'] == 'on'):  # Must be explicitly set for check to pass
                             self.evaluated_keys = ['database_version/[0]/POSTGRES',
                                                    f'{evaluated_keys_prefix}/[{flags.index(flag)}]/name',
                                                    f'{evaluated_keys_prefix}/[{flags.index(flag)}]/value']
-                            return CheckResult.FAILED
+                            return CheckResult.PASSED
                     self.evaluated_keys = ['database_version/[0]/POSTGRES', 'settings/[0]/database_flags']
-            return CheckResult.PASSED
+            return CheckResult.FAILED
         return CheckResult.UNKNOWN
 
 
