@@ -36,14 +36,14 @@ class GoogleCloudPostgreSqlLogLockWaits(BaseResourceCheck):
                         # [{'name': ['<key>'], 'value': ['<value>']},{'name': ['<key>'], 'value': ['<value>']}]
                         flags = [{key: flag[key][0] for key in flag} for flag in flags]
                     for flag in flags:
-                        if (flag['name'] == 'log_lock_waits') and (flag['value'] == 'off'):
+                        if (flag['name'] == 'log_lock_waits') and (flag['value'] == 'on'):  # Must be explicitly set for check to pass
                             self.evaluated_keys = ['database_version/[0]/POSTGRES',
                                                    f'{evaluated_keys_prefix}/[{flags.index(flag)}]/name',
                                                    f'{evaluated_keys_prefix}/[{flags.index(flag)}]/value']
-                            return CheckResult.FAILED
+                            return CheckResult.PASSED
                     self.evaluated_keys = ['database_version/[0]/POSTGRES', 'settings/[0]/database_flags']
 
-            return CheckResult.PASSED
+            return CheckResult.FAILED
         return CheckResult.UNKNOWN
 
 
