@@ -6,14 +6,14 @@ import logging
 import os
 import platform
 from pathlib import Path
-from typing import Dict, Optional, Tuple, List, Type, Any, Set, TYPE_CHECKING
+from typing import Dict, Optional, Tuple, Type, Any, Set, TYPE_CHECKING
 
 import dpath.util
 
 from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.checks_infra.registry import BaseRegistry
 from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
-from checkov.common.images.image_referencer import Image, ImageReferencerMixin
+from checkov.common.images.image_referencer import ImageReferencerMixin
 from checkov.common.output.extra_resource import ExtraResource
 from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.models.enums import CheckResult
@@ -23,7 +23,6 @@ from checkov.common.output.report import Report, merge_reports, remove_duplicate
 from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.runners.base_runner import BaseRunner, CHECKOV_CREATE_GRAPH
 from checkov.common.util import data_structures_utils
-from checkov.common.util.config_utils import should_scan_hcl_files
 from checkov.common.util.secrets import omit_secret_value_from_checks
 from checkov.common.variables.context import EvaluationContext
 from checkov.runner_filter import RunnerFilter
@@ -44,6 +43,7 @@ from checkov.terraform.tag_providers import get_resource_tags
 
 if TYPE_CHECKING:
     from networkx import DiGraph
+    from checkov.common.images.image_referencer import Image
 
 # Allow the evaluation of empty variables
 dpath.options.ALLOW_EMPTY_STRING_KEYS = True
@@ -52,34 +52,35 @@ CHECK_BLOCK_TYPES = frozenset(['resource', 'data', 'provider', 'module'])
 
 
 class Runner(ImageReferencerMixin, BaseRunner):
-    check_type = CheckType.TERRAFORM
+    check_type = CheckType.TERRAFORM  # noqa: CCE003  # a static attribute
 
     def __init__(
         self,
-        parser: Parser = Parser(),
-        db_connector: NetworkxConnector = NetworkxConnector(),
-        external_registries: Optional[List[BaseRegistry]] = None,
+        parser: Parser | None = None,
+        db_connector: NetworkxConnector | None = None,
+        external_registries: list[BaseRegistry] | None = None,
         source: str = "Terraform",
         graph_class: Type[TerraformLocalGraph] = TerraformLocalGraph,
-        graph_manager: Optional[TerraformGraphManager] = None
+        graph_manager: TerraformGraphManager | None = None
     ) -> None:
         super().__init__(file_extensions=['.tf', '.hcl'])
         self.external_registries = [] if external_registries is None else external_registries
         self.graph_class = graph_class
-        self.parser = parser
+        self.parser = parser or Parser()
         self.definitions = None
         self.context = None
         self.breadcrumbs = None
         self.evaluations_context: Dict[str, Dict[str, EvaluationContext]] = {}
         self.graph_manager: TerraformGraphManager = graph_manager if graph_manager is not None else TerraformGraphManager(
             source=source,
-            db_connector=db_connector)
+            db_connector=db_connector or NetworkxConnector(),
+        )
         self.graph_registry = get_graph_checks_registry(self.check_type)
-        self.definitions_with_modules: Dict[str, Dict] = {}
+        self.definitions_with_modules: dict[str, dict[str, Any]] = {}
         self.referrer_cache: Dict[str, str] = {}
         self.non_referred_cache: Set[str] = set()
 
-    block_type_registries = {
+    block_type_registries = {  # noqa: CCE003  # a static attribute
         'resource': resource_registry,
         'data': data_registry,
         'provider': provider_registry,
@@ -99,9 +100,8 @@ class Runner(ImageReferencerMixin, BaseRunner):
             self.pbar.turn_off_progress_bar()
 
         report = Report(self.check_type)
-        parsing_errors = {}
+        parsing_errors: dict[str, Exception] = {}
         self.load_external_checks(external_checks_dir)
-        scan_hcl = should_scan_hcl_files()
         local_graph = None
 
         if self.context is None or self.definitions is None or self.breadcrumbs is None:
@@ -124,7 +124,7 @@ class Runner(ImageReferencerMixin, BaseRunner):
                 files = [os.path.abspath(file) for file in files]
                 root_folder = os.path.split(os.path.commonprefix(files))[0]
                 self.parser.evaluate_variables = False
-                self._parse_files(files, scan_hcl, parsing_errors)
+                self._parse_files(files, parsing_errors)
 
                 if CHECKOV_CREATE_GRAPH:
                     local_graph = self.graph_manager.build_graph_from_definitions(self.definitions)
@@ -146,7 +146,7 @@ class Runner(ImageReferencerMixin, BaseRunner):
         self.pbar.initiate(len(self.definitions))  # type: ignore
         self.check_tf_definition(report, root_folder, runner_filter, collect_skip_comments)
 
-        report.add_parsing_errors(list(parsing_errors.keys()))
+        report.add_parsing_errors(parsing_errors.keys())
 
         if CHECKOV_CREATE_GRAPH:
             graph_report = self.get_graph_checks_report(root_folder, runner_filter)
@@ -417,12 +417,12 @@ class Runner(ImageReferencerMixin, BaseRunner):
                         )
                     )
 
-    def _parse_files(self, files, scan_hcl, parsing_errors):
+    def _parse_files(self, files, parsing_errors):
         def parse_file(file):
-            if not (file.endswith(".tf") or (scan_hcl and file.endswith(".hcl"))):
+            if not (file.endswith(".tf") or file.endswith(".hcl")):
                 return
             file_parsing_errors = {}
-            parse_result = self.parser.parse_file(file=file, parsing_errors=file_parsing_errors, scan_hcl=scan_hcl)
+            parse_result = self.parser.parse_file(file=file, parsing_errors=file_parsing_errors)
             # the exceptions type can un-pickleable so we need to cast them to Exception
             for path, e in file_parsing_errors.items():
                 file_parsing_errors[path] = Exception(e.__repr__())
@@ -494,7 +494,7 @@ class Runner(ImageReferencerMixin, BaseRunner):
 
         if not self.definitions_with_modules:
             self._prepare_definitions_with_modules()
-        for file, file_content in self.definitions_with_modules.items():
+        for file_content in self.definitions_with_modules.values():
             for modules in file_content["module"]:
                 for module_name, module_content in modules.items():
                     if "__resolved__" not in module_content:
@@ -508,19 +508,21 @@ class Runner(ImageReferencerMixin, BaseRunner):
         self.non_referred_cache.add(full_file_path)
         return None
 
-    def _prepare_definitions_with_modules(self):
-        def __cache_file_content(file_modules: list):
+    def _prepare_definitions_with_modules(self) -> None:
+        def __cache_file_content(file_name: str, file_modules: list[dict[str, Any]]) -> None:
             for modules in file_modules:
                 for module_content in modules.values():
                     if "__resolved__" in module_content:
-                        self.definitions_with_modules[file] = file_content
+                        self.definitions_with_modules[file_name] = file_content
                         return
 
         for file, file_content in self.definitions.items():
             if "module" in file_content:
-                __cache_file_content(file_modules=file_content["module"])
+                __cache_file_content(file_name=file, file_modules=file_content["module"])
 
-    def extract_images(self, graph_connector: DiGraph | None = None, resources: list[dict[str, Any]] | None = None) -> list[Image]:
+    def extract_images(
+        self, graph_connector: DiGraph | None = None, definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] | None = None
+    ) -> list[Image]:
         if not graph_connector:
             # should not happen
             return []
